import {connect, connection} from 'mongoose';
import { Post } from '../models/Post';
import { EStatuses } from '../enums/Estatuses';
import IPost from '../interfaces/IPost';
import IResponse from '../interfaces/IResponse';
import IPostDto from '../interfaces/IPostDto';

export const mongoose = {
	run: async () => {
		try {
			return await connect(`${process.env.MONGO_URL}/hw92`);
			
		} catch (error) {
			console.log(error);
		}
	},

	stop: async () => {
		try {
			return await connection.destroy();
		} catch (error) {
			console.log(error);
		}
	},
	getPosts: async(): Promise<IResponse<IPost[] | undefined>>=> {
		try{
			const data = await Post.find()
			const response: IResponse<IPost[]> = {
				status: EStatuses.OK,
				result: data as any,
				message: 'Posts found'
			}
			return response
		} catch (err: unknown) {
			const error = err as Error
			const response: IResponse<undefined> = {
				status: EStatuses.NOT_OK,
				result: undefined,
				message: error.message
			}
			return response
		}

	},
	getPostById: async(id: string): Promise<IResponse<IPost | undefined>>=> {
		try{
			const data = await Post.findById(id)
			const response: IResponse<IPost> = {
				status: EStatuses.OK,
				result: data as any,
				message: 'Post found'
			}
			return response
		} catch (err: unknown) {
			const error = err as Error
			const response: IResponse<undefined> = {
				status: EStatuses.NOT_OK,
				result: undefined,
				message: error.message
			}
			return response
		}
	},
	addPost: async(postDto: IPostDto): Promise<IResponse<IPost | undefined>>=> {
		try{
			const post = new Post(postDto)
			const data = await post.save()
			const response: IResponse<IPost> = {
				status: EStatuses.OK,
				result: data ,
				message: 'Post added'
			}
			return response
		} catch (err: unknown) {
			const error = err as Error
			const response: IResponse<undefined> = {
				status: EStatuses.NOT_OK,
				result: undefined,
				message: error.message
			}
			return response
		}
	},
	deletePostById: async(id: string): Promise<IResponse<IPost | undefined>>=> {
		try{
			const data = await Post.findOneAndDelete({_id:id})
			const response: IResponse<IPost> = {
				status: EStatuses.OK,
				result: data as any,
				message: 'Post deleted'
			}
			return response
		} catch (err: unknown) {
			const error = err as Error
			const response: IResponse<undefined> = {
				status: EStatuses.NOT_OK,
				result: undefined,
				message: error.message
			}
			return response
		}
	}
	
};


